==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d2/de4/autoreplace__cmd_8cpp.js <==
var autoreplace__cmd_8cpp =
[
    [ "BuildReplacementVehicle", "d2/de4/autoreplace__cmd_8cpp.html#a31a987004320db8337817beb99be49e4", null ],
    [ "ChangeVehicleNews", "d2/de4/autoreplace__cmd_8cpp.html#a858330365a0e288a76f22d591b621e91", null ],
    [ "ChangeVehicleViewports", "d2/de4/autoreplace__cmd_8cpp.html#a5e4932051125f5ef9d5efbf28e89e207", null ],
    [ "ChangeVehicleViewWindow", "d2/de4/autoreplace__cmd_8cpp.html#a8a07b2eac224f1223a82b695cb5b8d5b", null ],
    [ "CheckAutoreplaceValidity", "d2/de4/autoreplace__cmd_8cpp.html#aacb2ff1c1d8f7c3dabab2900caa17daf", null ],
    [ "CheckCargoCapacity", "d2/de4/autoreplace__cmd_8cpp.html#a42a93a55d862d41641d3334b553e5d64", null ],
    [ "CmdAutoreplaceVehicle", "d2/de4/autoreplace__cmd_8cpp.html#aa0d76a4dd7edceb23604069486deed27", null ],
    [ "CmdMoveVehicle", "d2/de4/autoreplace__cmd_8cpp.html#aebe50d241bced140190333577caa84c2", null ],
    [ "CmdSetAutoReplace", "d2/de4/autoreplace__cmd_8cpp.html#adbc96dfb8470d4f81cbfa62cba6244bf", null ],
    [ "CmdStartStopVehicle", "d2/de4/autoreplace__cmd_8cpp.html#aa71ff7ee564cd0cf3ecbff4c4b88808d", null ],
    [ "CopyHeadSpecificThings", "d2/de4/autoreplace__cmd_8cpp.html#af705dda8b4a0ba43f6b5fe1d9cb69aa6", null ],
    [ "EnginesHaveCargoInCommon", "d2/de4/autoreplace__cmd_8cpp.html#a9da7c494166a9bbd4985c35a4e89627f", null ],
    [ "GetNewCargoTypeForReplace", "d2/de4/autoreplace__cmd_8cpp.html#a119a154806c6d8d013b295e38c5d6a4b", null ],
    [ "GetNewEngineType", "d2/de4/autoreplace__cmd_8cpp.html#abb613bb0a65e66eed9d0a791496f3064", null ],
    [ "ReplaceChain", "d2/de4/autoreplace__cmd_8cpp.html#a270ad1550eea2bc6f5286bf179f86014", null ],
    [ "ReplaceFreeUnit", "d2/de4/autoreplace__cmd_8cpp.html#acf68de48e60706057064867e2e9553eb", null ],
    [ "TransferCargo", "d2/de4/autoreplace__cmd_8cpp.html#ac05e8725daa2e121c4fa61df3e21f01f", null ],
    [ "VerifyAutoreplaceRefitForOrders", "d2/de4/autoreplace__cmd_8cpp.html#aa3222d61de02ea0c359779a9aa77d38b", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d2/de4/autoreplace__cmd_8cpp.js <==
var autoreplace__cmd_8cpp =
[
    [ "BuildReplacementVehicle", "d2/de4/autoreplace__cmd_8cpp.html#a31a987004320db8337817beb99be49e4", null ],
    [ "ChangeVehicleNews", "d2/de4/autoreplace__cmd_8cpp.html#a858330365a0e288a76f22d591b621e91", null ],
    [ "ChangeVehicleViewports", "d2/de4/autoreplace__cmd_8cpp.html#a5e4932051125f5ef9d5efbf28e89e207", null ],
    [ "ChangeVehicleViewWindow", "d2/de4/autoreplace__cmd_8cpp.html#a8a07b2eac224f1223a82b695cb5b8d5b", null ],
    [ "CheckAutoreplaceValidity", "d2/de4/autoreplace__cmd_8cpp.html#aacb2ff1c1d8f7c3dabab2900caa17daf", null ],
    [ "CheckCargoCapacity", "d2/de4/autoreplace__cmd_8cpp.html#a42a93a55d862d41641d3334b553e5d64", null ],
    [ "CmdAutoreplaceVehicle", "d2/de4/autoreplace__cmd_8cpp.html#aa0d76a4dd7edceb23604069486deed27", null ],
    [ "CmdMoveVehicle", "d2/de4/autoreplace__cmd_8cpp.html#aebe50d241bced140190333577caa84c2", null ],
    [ "CmdSetAutoReplace", "d2/de4/autoreplace__cmd_8cpp.html#adbc96dfb8470d4f81cbfa62cba6244bf", null ],
    [ "CmdStartStopVehicle", "d2/de4/autoreplace__cmd_8cpp.html#aa71ff7ee564cd0cf3ecbff4c4b88808d", null ],
    [ "CopyHeadSpecificThings", "d2/de4/autoreplace__cmd_8cpp.html#af705dda8b4a0ba43f6b5fe1d9cb69aa6", null ],
    [ "EnginesHaveCargoInCommon", "d2/de4/autoreplace__cmd_8cpp.html#a9da7c494166a9bbd4985c35a4e89627f", null ],
    [ "GetIncompatibleRefitOrderIdForAutoreplace", "d2/de4/autoreplace__cmd_8cpp.html#a0b00a18b94bc4b4dae1a7fea5349033b", null ],
    [ "GetNewCargoTypeForReplace", "d2/de4/autoreplace__cmd_8cpp.html#a119a154806c6d8d013b295e38c5d6a4b", null ],
    [ "GetNewEngineType", "d2/de4/autoreplace__cmd_8cpp.html#abb613bb0a65e66eed9d0a791496f3064", null ],
    [ "ReplaceChain", "d2/de4/autoreplace__cmd_8cpp.html#a270ad1550eea2bc6f5286bf179f86014", null ],
    [ "ReplaceFreeUnit", "d2/de4/autoreplace__cmd_8cpp.html#acf68de48e60706057064867e2e9553eb", null ],
    [ "TransferCargo", "d2/de4/autoreplace__cmd_8cpp.html#ac05e8725daa2e121c4fa61df3e21f01f", null ],
    [ "VerifyAutoreplaceRefitForOrders", "d2/de4/autoreplace__cmd_8cpp.html#aa3222d61de02ea0c359779a9aa77d38b", null ]
];
